Learn R Programming

greenR (version 0.0.1.6)

calculate_percentage: Calculate the percentage of edges with their respective green index category

Description

This function calculates the percentage of edges within each green index category.

Usage

calculate_percentage(green_index_data)

Value

A data frame with the percentage of each green index category.

Arguments

green_index_data

A data frame containing the calculated green index values for each edge.

Examples

Run this code
if (FALSE) {
# Generate a sample green_index data frame
green_index_data <- data.frame(
  green_index = runif(1000)
)
calculate_percentage(green_index_data)
}

Run the code above in your browser using DataLab