Learn R Programming

greenR (version 0.0.1.6)

save_as_leaflet: Save the green index data as a Leaflet map in an HTML file

Description

This function saves the green index data as a Leaflet map in an HTML file.

Usage

save_as_leaflet(edges, file_path)

Value

No return value, called for side effects

Arguments

edges

A data frame containing the calculated green index values for each edge.

file_path

The file path where the HTML file will be saved.

Examples

Run this code
if (FALSE) {
# Assuming you have already obtained green index data
save_as_leaflet(green_index, "green_index_map.html")
}

Run the code above in your browser using DataLab