Learn R Programming

greenR (version 0.0.1.6)

visualize_green_spaces: Visualize Green Spaces on a Leaflet Map

Description

This function visualizes green spaces on a Leaflet map using the green_areas_data obtained from the get_osm_data function. Green spaces are labeled based on their tags and have different colors in the legend. Users can switch the green spaces layer on and off.

Usage

visualize_green_spaces(green_areas_data)

Value

A Leaflet map displaying green spaces with labels and a legend, with a layer control for toggling the green spaces layer.

Arguments

green_areas_data

List containing green areas data (obtained from get_osm_data function).

Examples

Run this code
if (FALSE) {
  # Assuming you have already obtained green_areas_data using get_osm_data
  visualize_green_spaces(green_areas_data)
}

Run the code above in your browser using DataLab