powered by
This function calculates the percentage of edges within each green index category.
calculate_percentage(green_index_data)
A data frame with the percentage of each green index category.
A data frame containing the calculated green index values for each edge.
if (FALSE) { # Generate a sample green_index data frame green_index_data <- data.frame( green_index = runif(1000) ) calculate_percentage(green_index_data) }
Run the code above in your browser using DataLab