powered by
This function saves the green index data as a Leaflet map in an HTML file.
save_as_leaflet(edges, file_path)
No return value, called for side effects
A data frame containing the calculated green index values for each edge.
The file path where the HTML file will be saved.
if (FALSE) { # Assuming you have already obtained green index data save_as_leaflet(green_index, "green_index_map.html") }
Run the code above in your browser using DataLab